# 바이로 문서

Vyro는 고성능 API를 위해 Python DX와 Rust 실행 엔진을 결합합니다.

## 당신이 할 수 있는 일

- `Vyro()`로 비동기 API 구축
- `vyro run`로 서비스 실행
- OpenAPI로 API 계약 생성
- 관찰 가능성 및 보안 기본 요소를 갖춘 프로덕션 서비스 운영

## 여기서 시작하세요

1. [설치](getting-started/installation.md)를 읽어보세요.
2. [빠른 시작](getting-started/quickstart.md)을 따르세요.
3. [첫 번째 API](getting-started/first-api.md)에서 첫 번째 엔드포인트를 구축하세요.